@@ -100,8 +100,9 @@ class ModuleList (gtk.ListStore):
         to the row containg the module. If there's no such row, it will append it.
         """
         for mod in self:
-            if mod == module:
+            if mod.__class__.__name__ == module.__class__.__name__:
                 # We don't want a duplicate module
+                LOGGER.warning("You tried to add a module twice. Not adding %r from %s", mod, mod.get_filename())
                 return
                 
         if iter is None:
@@ -139,8 +140,11 @@ class ModuleList (gtk.ListStore):
     def module_toggled_cb (self, sender, module):
         """
         Callback to toggle the enabled state of the module.
-        """
-        self[self.get_position_from_context(module)[0]][self.ENABLED_COL] = module.is_enabled()
+        """ 
+        iter, index = self.get_position_from_context(module)
+        if iter != None:
+            # Only if the module is in the list
+            self[iter][self.ENABLED_COL] = module.is_enabled()
         
     def is_module_enabled(self, iter):
         return self[iter][self.ENABLED_COL]
