@@ -4,16 +4,19 @@ import sys
 from os.path import abspath, join, dirname, exists
 import logging
 import gettext, locale
+from gettext import gettext as _
 import gnomeapplet
 from optparse import OptionParser
 
 # Return a standalone window that holds the applet
 def build_window():
     app = gtk.Window(gtk.WINDOW_TOPLEVEL)
-    app.set_title("Deskbar Applet")
+    # translators: This is the window title.
+    app.set_title(_("Deskbar Applet"))
     app.connect("destroy", gtk.main_quit)
     
     applet = gnomeapplet.Applet()
+    applet.set_flags(applet.flags() | gnomeapplet.EXPAND_MINOR)
     applet.get_orient = lambda: gnomeapplet.ORIENT_DOWN
     applet_factory(applet, None)
     applet.reparent(app)
@@ -23,9 +26,9 @@ def build_window():
     return app
 
 def applet_factory(applet, iid):
-    print 'Starting Deskbar instance:', applet, iid
-    dapplet = DeskbarApplet(applet)
-    applet.add(dapplet)
+    logging.info ('Starting Deskbar instance: %s %s', applet, iid)
+    tray = DeskbarTray(applet)
+    applet.add(tray)
     
     applet.show_all()
     return True
@@ -38,8 +41,7 @@ def check_deskbar_path ():
     	logging.info ("Running uninstalled, adding %s to system path" % abspath(root_dir))
 
 # Setup logging
-logging.basicConfig(level=logging.DEBUG, format='%(levelname)-8s %(message)s',)
-logging.getLogger("deskbar-applet")
+logging.basicConfig(level=logging.DEBUG, format='%(asctime)s %(name)-12s %(levelname)-8s %(message)s', datefmt='%m-%d %H:%M')
 
 # Delay loading of deskbar modules until we have the path set up,
 # to allow running in uninstalled mode
@@ -47,7 +49,7 @@ check_deskbar_path()
 import deskbar
 import deskbar.defs
 import deskbar.gtkexcepthook
-from deskbar.ui.DeskbarApplet import DeskbarApplet
+from deskbar.ui.DeskbarTray import DeskbarTray
 
 # Setup i18n
 gettext.bindtextdomain('deskbar-applet', abspath(join(deskbar.defs.DATA_DIR, "locale")))
