@@ -1,4 +1,5 @@
 from deskbar.core.Utils import is_program_in_path, load_icon
+from deskbar.core.Categories import CATEGORIES
 from deskbar.defs import VERSION
 from deskbar.handlers.actions.ActionsFactory import get_actions_for_uri
 from deskbar.handlers.actions.OpenWithApplicationAction import OpenWithApplicationAction
@@ -6,6 +7,7 @@ from deskbar.handlers.actions.OpenFileAction import OpenFileAction
 from deskbar.handlers.actions.ShowUrlAction import ShowUrlAction
 from gettext import gettext as _
 from os.path import basename
+from gobject import GError
 import cgi, re
 import deskbar, deskbar.interfaces.Module
 import deskbar.interfaces.Match
@@ -13,6 +15,8 @@ import gnomevfs
 import logging
 import threading
 
+LOGGER = logging.getLogger(__name__)
+
 MAX_RESULTS = 20 # per handler
 HANDLERS = ["BeagleLiveHandler"]
 
@@ -193,8 +197,27 @@ class OpenBeagleFileAction(OpenFileAction):
         
     def get_hash(self):
         return self._complete_uri
+
+class BeagleSearchAction(OpenWithApplicationAction):
+    def __init__(self, name, term, verb):
+    	OpenWithApplicationAction.__init__(self, name, "beagle-search", [term])
+    	self._verb = verb
+
+    def get_verb(self):
+    	return self._verb
     
 ### ===== End: Actions ===== ###
+
+class BeagleSearchMatch(deskbar.interfaces.Match):
+    def __init__(self, term, cat_type, **args):
+    	deskbar.interfaces.Match.__init__(self, name=term, icon= "system-search", category=cat_type, **args)
+    	verb = _("Additional results for category <b>%s</b>") % _(CATEGORIES[cat_type]['name'])
+    	self.term = term
+    	self.add_action( BeagleSearchAction("Beagle Search", term, verb) )
+    	self.set_priority(self.get_priority()-50)
+    
+    def get_hash(self, text=None):
+    	return "beagle-search "+self.term
         
 class BeagleLiveMatch (deskbar.interfaces.Match):
     def __init__(self, result=None, **args):
@@ -238,7 +261,7 @@ class BeagleLiveMatch (deskbar.interfaces.Match):
                                             )
             self.add_all_actions( actions )
         else:
-            logging.warning("Unknown beagle match type found: "+result["type"] )
+            LOGGER.warning("Unknown beagle match type found: "+result["type"] )
 
         # Load the correct icon
         
@@ -281,6 +304,7 @@ class BeagleLiveHandler(deskbar.interfaces.Module):
         # a new key in inserted and it isn't removed
         # therefore, dict is getting bigger and bigger
         self.counter = {}
+        self.beagle_search_match_emited = False
         self.__lock = threading.Lock()
         
     def initialize (self):
@@ -288,19 +312,24 @@ class BeagleLiveHandler(deskbar.interfaces.Module):
    
     def query (self, qstring):
         self.counter[qstring] = {}
+        self.beagle_search_match_emited = False
         self.__lock.acquire()
         self.hits = {}
         self.__lock.release()
         self.beagle_query = beagle.Query()
         self.beagle_query.add_text(qstring)
         self.beagle_query.connect("hits-added", self.hits_added, qstring, MAX_RESULTS)
-        self.beagle.send_request_async(self.beagle_query)
+        try:
+            self.beagle.send_request_async(self.beagle_query)
+        except GError, e:
+            LOGGER.exception(e)
+            del self.counter[qstring]
        
     def hits_added(self, query, response, qstring, qmax):
         hit_matches = []
         for hit in response.get_hits():
             if hit.get_type() not in TYPES:
-                logging.info("Beagle live seen an unknown type:"+ hit.get_type())
+                LOGGER.info("Beagle live seen an unknown type:"+ str(hit.get_type()))
                 continue
             
             if "snippet" in TYPES[hit.get_type()] and TYPES[hit.get_type()]["snippet"]:
@@ -311,7 +340,13 @@ class BeagleLiveHandler(deskbar.interfaces.Module):
                 hit.ref()
                 snippet_request.connect('response', self._on_snippet_received, query, container, qstring, qmax)
                 snippet_request.connect('closed', self._on_snippet_closed, query, container, qstring, qmax)
-                self.beagle.send_request_async(snippet_request)
+                try:
+                    self.beagle.send_request_async(snippet_request)
+                except GError, e:
+                    LOGGER.exception(e)
+                    hit.unref()
+                    continue
+                    
                 try:
                     self.__lock.acquire()
                     self.hits[hit] = snippet_request
@@ -343,6 +378,7 @@ class BeagleLiveHandler(deskbar.interfaces.Module):
             if container.hit in self.hits:
                 if container.snippet == None:
                     self._on_hit_added(query, container, qstring, qmax)
+                    self.counter[qstring][container.hit.get_type()] -= 1
                 del self.hits[container.hit]
             container.hit.unref()
         finally:
@@ -364,16 +400,28 @@ class BeagleLiveHandler(deskbar.interfaces.Module):
               
         if not hit_type in self.counter[qstring]:
             self.counter[qstring][hit_type] = 0
-
-        if self.counter[qstring][hit_type] >= qmax:
-            return
-            
-        hit_type_data = TYPES[hit_type]
         
+        self.counter[qstring][hit_type] += 1
+            
         result = {
             "uri":  hit.get_uri(),
             "type": hit_type,
         }
+        
+        if TYPES.has_key(result["type"]):
+            cat_type = TYPES[result["type"]]["category"]
+        else:
+            cat_type = "default"
+
+        if self.counter[qstring][hit_type] >= qmax:
+            if(not self.beagle_search_match_emited):
+            	self.beagle_search_match_emited = True
+            	match = BeagleSearchMatch(qstring, cat_type)
+            	self._emit_query_ready(qstring, [match])
+            	return match
+            return
+            
+        hit_type_data = TYPES[hit_type]
           
         name = None
         for prop in hit_type_data["name"]:
@@ -432,13 +480,6 @@ class BeagleLiveHandler(deskbar.interfaces.Module):
             result["snippet"] = "\n<span size='small' style='italic'>%s</span>" % cgi.escape(tmp)
         else:
             result["snippet"] = ""
-            
-        self.counter[qstring][hit.get_type()] = self.counter[qstring][hit_type] +1
-
-        if TYPES.has_key(result["type"]):
-            cat_type = TYPES[result["type"]]["category"]
-        else:
-            cat_type = "default"
         
         match = BeagleLiveMatch(result, category=cat_type, priority=self.get_priority())
         
