@@ -68,6 +68,7 @@ def get_firefox_home_file(needed_file):
 def get_firefox_version():
     browser = get_preferred_browser ()
     process = subprocess.Popen(browser + " -version", stdout=subprocess.PIPE, shell=True)
+    process.wait()
     info = process.stdout.readline().split(" ")
     pattern = re.compile("([0-9]+?)\.([0-9]+?)(\.([0-9]+))*")
     version = None
@@ -107,14 +108,13 @@ PRIMARY_SEARCH_ENGINE = "Google"
 try:
     if USING_FIREFOX:
         prefs_file = file(get_firefox_home_file("prefs.js"))
-    else:
-        # TODO - similar functionality for old-school mozilla (not firefox)
-        prefs_file = None
-    for line in prefs_file:
-        if line.startswith('user_pref("browser.search.selectedEngine", "'):
-            line = line.strip()
-            PRIMARY_SEARCH_ENGINE = line[len('user_pref("browser.search.selectedEngine", "'):-len('");')]
-            break
+        for line in prefs_file:
+            if line.startswith('user_pref("browser.search.selectedEngine", "'):
+                line = line.strip()
+                PRIMARY_SEARCH_ENGINE = line[len('user_pref("browser.search.selectedEngine", "'):-len('");')]
+                break
+        prefs_file.close()
+    # TODO - similar functionality for old-school mozilla (not firefox)
 except:
     pass
 
@@ -209,7 +209,7 @@ class MozillaBookmarksHandler(deskbar.interfaces.Module):
     def has_requirements():
         if is_preferred_browser("mozilla"):
             return True
-        elif is_preferred_browser("firefox"):
+        elif is_preferred_browser("firefox") or is_preferred_browser("iceweasel"):
             if MozillaBookmarksHandler.has_firefox_version():
                 return True
             # TODO: mark as i18n
@@ -822,7 +822,7 @@ class MozillaHistoryHandler(deskbar.interfaces.Module):
     def has_requirements():
         if is_preferred_browser("mozilla"):
             return True
-        elif is_preferred_browser("firefox"):
+        elif is_preferred_browser("firefox") or is_preferred_browser("iceweasel"):
             if MozillaBookmarksHandler.has_firefox_version():
                 return True
             # TODO: mark as i18n
