@@ -77,12 +77,21 @@ class Core(gobject.GObject):
     def get_window_height(self):
         raise NotImplementedError
     
+    def get_window_x(self):
+        raise NotImplementedError
+        
+    def get_window_y(self):
+        raise NotImplementedError
+    
     def get_hide_after_action(self):
         raise NotImplementedError
     
     def get_max_history_items(self):
         raise NotImplementedError
     
+    def get_ui_name(self):
+        raise NotImplementedError
+    
     def set_keybinding(self, binding):
         raise NotImplementedError
     
@@ -116,12 +125,21 @@ class Core(gobject.GObject):
     def set_window_height(self, height):
         raise NotImplementedError
    
+    def set_window_x(self, x):
+        raise NotImplementedError
+        
+    def set_window_y(self, y):
+        raise NotImplementedError
+   
     def set_hide_after_action(self, val):
         raise NotImplementedError
     
     def set_max_history_items(self, amount):
         raise NotImplementedError
     
+    def set_ui_name(self, name):
+        raise NotImplementedError
+    
     def get_history(self):
         """
         Returns History object
